scikit-image: image processing in Python
========================================

`scikit-image <https://scikit-image.org>`__ builds on
`scipy.ndimage <https://docs.scipy.org/doc/scipy/reference/ndimage.html>`__ to
provide a versatile set of image processing routines in `Python
<https://www.python.org>`_.

This library is developed by its community, and `contributions
<contribute>`_ are most welcome!

Read about our `mission, vision, and values <values.html>`_ and how we
`govern <skips/0-governance.html>`_ the project.

Major proposals to the project are documented in `SKIPs <skips/index.html>`_.

Homepage
--------
https://scikit-image.org

User Forum
----------
https://forum.image.sc/tags/scikit-image

Developer Mailing List
----------------------
https://mail.python.org/mailman3/lists/scikit-image.python.org/

Source, bugs, and patches
-------------------------
https://github.com/scikit-image/scikit-image

Contact
-------
Stefan van der Walt <stefanv at berkeley.edu>
